==> haskell-hls-explicit-imports-plugin-2.0.0.0-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-imports-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-imports-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-explicit-imports-plugin-2.0.0.0-EvVvRHTNbJICD0jV94D473
key:                  hls-explicit-imports-plugin-2.0.0.0-EvVvRHTNbJICD0jV94D473
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Explicit imports plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  b67c5dcd2e4dda7b2a12fe45d1d4d8a5
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitImports
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-imports-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-imports-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-imports-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-imports-plugin
hs-libraries:
    HShls-explicit-imports-plugin-2.0.0.0-EvVvRHTNbJICD0jV94D473

depends:
    aeson-2.1.2.1-G4Y2VMvw6jlHlUlOzfqhge base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 ghc-9.4.8 ghcide-2.0.0.0-2OoOssIvpRZJ70cxoplPUd
    hls-graph-2.0.0.0-6aKGFDEwcZ2Gewpz8C2a3M
    hls-plugin-api-2.0.0.0-CjPH3i9n95sAzh7VU9zzvQ
    lsp-1.6.0.0-EzZWHSTgh2eBqXWsr3rUZN text-2.0.2
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-imports-plugin/html/hls-explicit-imports-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-imports-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-explicit-imports-plugin-2.0.0.0-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-imports-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-imports-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-explicit-imports-plugin-2.0.0.0-KYs4ksLwr947OqSAjWOLTW
key:                  hls-explicit-imports-plugin-2.0.0.0-KYs4ksLwr947OqSAjWOLTW
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Explicit imports plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  e774d9cd1c720cc6d704cb610ab944d2
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitImports
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-imports-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-imports-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-imports-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-imports-plugin
hs-libraries:
    HShls-explicit-imports-plugin-2.0.0.0-KYs4ksLwr947OqSAjWOLTW

depends:
    aeson-2.1.2.1-6acn88DzD1XA00qNRJAJcm base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 ghc-9.4.8 ghcide-2.0.0.0-JBnXoVvu65M12CKXEjB8Bf
    hls-graph-2.0.0.0-JxXRDWFaqbJLJVHXjOUi26
    hls-plugin-api-2.0.0.0-7JHQKy5I48iFHpRVjutX3t
    lsp-1.6.0.0-96SGiU71mGvLtJoU3VZPoO text-2.0.2
    unordered-containers-0.2.20-2kG5VEC3Gy42AwINT9WJ9w

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-imports-plugin/html/hls-explicit-imports-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-imports-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
